/*
 * test
 *
 * Copyright (c) 2020 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "test.h"
#include <device/pmqos-internal.h>

#define METHOD_APP_LAUNCH_HOME		"AppLaunchHome"
#define METHOD_HOMESCREEN		"HomeScreen"

static bool pmqos_app_launch_home(void)
{
	int ret;

	ret = device_pmqos_app_launch_home(3000);

	return capi_result(METHOD_APP_LAUNCH_HOME, ret);
}

static bool pmqos_homescreen(void)
{
	int ret;

	ret = device_pmqos_homescreen(3000);

	return capi_result(METHOD_HOMESCREEN, ret);
}

static void pmqos_test_all(int *success, int *fail)
{
	int s = 0;
	int f = 0;

	(pmqos_app_launch_home())	? s++ : f++;
	(pmqos_homescreen())		? s++ : f++;

	if (NULL != success)    	*success = s;
	if (NULL != fail)       	*fail = f;
}

static void pmqos_init(void *data)
{
	int success = 0;
	int fail = 0;

	_I("start test");

	pmqos_test_all(&success, &fail);

	_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
}

static void pmqos_exit(void *data)
{
	_I("end test");
}

static int pmqos_unit(int argc, char **argv)
{
	if (argc < 4) {
		int success = 0;
		int fail = 0;

		_I("start test");
		pmqos_test_all(&success, &fail);
		_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
	} else if (0 == strcasecmp(argv[3], METHOD_APP_LAUNCH_HOME)) {
		pmqos_app_launch_home();
	} else if (0 == strcasecmp(argv[3], METHOD_HOMESCREEN)) {
		pmqos_homescreen();
	} else {
		_E("Unknown test case!!!");
	}

	return 0;
}

static const struct test_ops pmqos_test_ops = {
	.priority = TEST_PRIORITY_NORMAL,
	.name     = "pmqos",
	.init     = pmqos_init,
	.exit    = pmqos_exit,
	.unit    = pmqos_unit,
};

TEST_OPS_REGISTER(&pmqos_test_ops)
