/*
 * deviced
 *
 * Copyright (c) 2012 - 2013 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __BATTERY_OPS_H__
#define __BATTERY_OPS_H__

#include <errno.h>
#include "core/common.h"
#include "power-supply.h"
#include <libsyscommon/dbus-system.h>

struct battery_ops {
	char *name;
	void (*init) (void *data);
	void (*exit) (void *data);
	int (*func) (unsigned int cmd, void *arg);
};

struct battery_plugin {
	void *handle;
	/* low battery notification */
	int (*lowbat_noti_launch) (int capacity, int option);
	void (*lowbat_noti_clean) (const char *prev, const char *str);

	int (*changed_battery_cf) (int status);
	void (*remove_health_popup) (void);

	int (*display_changed) (void *);
	int (*check_power_supply_noti) (void);
	void (*update_ovp) (enum battery_noti_status status);
	/* Add plugins here */
};

void add_battery(const struct battery_ops *batt);
void remove_battery(const struct battery_ops *batt);
const struct battery_ops *find_battery_feature(const char *name);

void battery_ops_init(void *data);
void battery_ops_exit(void *data);

#define BATTERY_OPS_REGISTER(batt)	\
static void __CONSTRUCTOR__ module_init(void)	\
{	\
	add_battery(batt);	\
}	\
static void __DESTRUCTOR__ module_exit(void)	\
{	\
	remove_battery(batt);	\
}

#define FIND_BATTERY(dev, name) do { \
	if (!dev) dev = find_battery_feature(name); \
} while (0)


#endif
