/*
 * deviced
 *
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include <stdio.h>

#include "util.h"
#include "core.h"
#include "display-ops.h"
#include "core/list.h"
#include "core/common.h"

static int pm_cur_state;
static int pm_old_state;
static unsigned int pm_status_flag;

inline int get_pm_cur_state(void)
{
	return pm_cur_state;
}

inline void set_pm_cur_state(int cur_state)
{
	pm_cur_state = cur_state;
}

inline int get_pm_old_state(void)
{
	return pm_old_state;
}

inline void set_pm_old_state(int old_state)
{
	pm_old_state = old_state;
}

inline unsigned int get_pm_status_flag(void)
{
	return pm_status_flag;
}

inline void set_pm_status_flag(unsigned int status_flag)
{
	pm_status_flag |= status_flag;
}

inline void clear_pm_status_flag(unsigned int status_flag)
{
	pm_status_flag &= ~status_flag;
}

void lcd_direct_control(enum dpms_state state, int flags)
{
	const struct device_ops *ops = NULL;
	dd_list *l = NULL;

	switch (state) {
	case DPMS_ON:
		DD_LIST_FOREACH(lcdon_ops, l, ops)
			ops->start(flags);
		break;
	case DPMS_OFF:
		DD_LIST_FOREACH(lcdon_ops, l, ops)
			ops->stop(flags);
		break;
	default:
		_E("state is wrong value %d", state);
		break;
	}
}

